# mypy-boto3-devicefarm

[![PyPI - mypy-boto3-devicefarm](https://img.shields.io/pypi/v/mypy-boto3-devicefarm.svg?color=blue)](https://pypi.org/project/mypy-boto3-devicefarm)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-devicefarm.svg?color=blue)](https://pypi.org/project/mypy-boto3-devicefarm)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.DeviceFarm 1.14.30](https://boto3.amazonaws.com/v1/documentation/api/1.14.30/reference/services/devicefarm.html#DeviceFarm) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `DeviceFarm` service.

```bash
python -m pip install boto3-stubs[devicefarm]
```

## How to use

### Client annotations

`DeviceFarmClient` provides annotations for `boto3.client("devicefarm")`.

```python
import boto3

from mypy_boto3_devicefarm import DeviceFarmClient
from mypy_boto3_devicefarm.paginator import (
    GetOfferingStatusPaginator,
    ListArtifactsPaginator,
    ListDeviceInstancesPaginator,
    ListDevicePoolsPaginator,
    ListDevicesPaginator,
    ListInstanceProfilesPaginator,
    ListJobsPaginator,
    ListNetworkProfilesPaginator,
    ListOfferingPromotionsPaginator,
    ListOfferingsPaginator,
    ListOfferingTransactionsPaginator,
    ListProjectsPaginator,
    ListRemoteAccessSessionsPaginator,
    ListRunsPaginator,
    ListSamplesPaginator,
    ListSuitesPaginator,
    ListTestsPaginator,
    ListUniqueProblemsPaginator,
    ListUploadsPaginator,
    ListVPCEConfigurationsPaginator,
)
from mypy_boto3_devicefarm.type_defs import AccountSettingsTypeDef, ...

client: DeviceFarmClient = boto3.client("devicefarm")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: DeviceFarmClient = session.client("devicefarm")
```

### Paginators annotations

`mypy_boto3_devicefarm.paginator` module contains type annotations for all paginators.

```python

client: DeviceFarmClient = boto3.client("devicefarm")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_offering_status_paginator: GetOfferingStatusPaginator = client.get_paginator("get_offering_status")
list_artifacts_paginator: ListArtifactsPaginator = client.get_paginator("list_artifacts")
list_device_instances_paginator: ListDeviceInstancesPaginator = client.get_paginator("list_device_instances")
list_device_pools_paginator: ListDevicePoolsPaginator = client.get_paginator("list_device_pools")
list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
list_instance_profiles_paginator: ListInstanceProfilesPaginator = client.get_paginator("list_instance_profiles")
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_network_profiles_paginator: ListNetworkProfilesPaginator = client.get_paginator("list_network_profiles")
list_offering_promotions_paginator: ListOfferingPromotionsPaginator = client.get_paginator("list_offering_promotions")
list_offering_transactions_paginator: ListOfferingTransactionsPaginator = client.get_paginator("list_offering_transactions")
list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
list_remote_access_sessions_paginator: ListRemoteAccessSessionsPaginator = client.get_paginator("list_remote_access_sessions")
list_runs_paginator: ListRunsPaginator = client.get_paginator("list_runs")
list_samples_paginator: ListSamplesPaginator = client.get_paginator("list_samples")
list_suites_paginator: ListSuitesPaginator = client.get_paginator("list_suites")
list_tests_paginator: ListTestsPaginator = client.get_paginator("list_tests")
list_unique_problems_paginator: ListUniqueProblemsPaginator = client.get_paginator("list_unique_problems")
list_uploads_paginator: ListUploadsPaginator = client.get_paginator("list_uploads")
list_vpce_configurations_paginator: ListVPCEConfigurationsPaginator = client.get_paginator("list_vpce_configurations")
```







### Typed dictionations

`mypy_boto3_devicefarm.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AccountSettingsTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_devicefarm` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("devicefarm")

session_client = boto3.Session().client("devicefarm")
```
